@@ -1,5 +1,6 @@
 import os
 import tarfile
+import zipfile
 
 import torch
 from PIL import Image
@@ -9,7 +10,11 @@ from ..utils import common_functions as c_f
 
 
 class BaseDataset(torch.utils.data.Dataset):
-    def __init__(self, domain):
+    """
+    Base dataset class
+    """
+
+    def __init__(self, domain: str):
         super().__init__()
         self.domain = domain
 
@@ -29,7 +34,16 @@ class BaseDataset(torch.utils.data.Dataset):
 
 
 class BaseDownloadableDataset(BaseDataset):
-    def __init__(self, root, download=False, **kwargs):
+    """
+    Allows automatic downloading of datasets.
+    """
+
+    def __init__(self, root: str, download: bool = False, **kwargs):
+        """
+        Arguments:
+            root: Folder where dataset will be downloaded to.
+            download: If True, will download the dataset if it hasn't already been downloaded.
+        """
         super().__init__(**kwargs)
         if download:
             try:
@@ -45,5 +59,7 @@ class BaseDownloadableDataset(BaseDataset):
 
     def download_dataset(self, root):
         download_url(self.url, root, filename=self.filename, md5=self.md5)
-        with tarfile.open(os.path.join(root, self.filename), "r:gz") as tar:
-            tar.extractall(path=root, members=c_f.extract_progress(tar))
+        filepath = os.path.join(root, self.filename)
+        decompressor = tarfile.open if tarfile.is_tarfile(filepath) else zipfile.ZipFile
+        with decompressor(filepath, "r") as f:
+            f.extractall(path=root, members=c_f.extract_progress(f))
