@@ -9,7 +9,7 @@ from .utils import ChainHook
 
 class VATHook(BaseWrapperHook):
     """
-    Applies the [```VATLoss```][pytorch_adapt.layers.vat_loss.VATLoss].
+    Applies the [```VATLoss```][pytorch_adapt.layers.VATLoss].
     """
 
     def __init__(self, loss_fn=None, **kwargs):
@@ -17,8 +17,8 @@ class VATHook(BaseWrapperHook):
         self.loss_fn = c_f.default(loss_fn, VATLoss, {})
         self.hook = FeaturesAndLogitsHook()
 
-    def call(self, losses, inputs):
-        outputs = self.hook(losses, inputs)[1]
+    def call(self, inputs, losses):
+        outputs = self.hook(inputs, losses)[0]
         [src_imgs, target_imgs, combined_model] = c_f.extract(
             inputs, ["src_imgs", "target_imgs", "combined_model"]
         )
@@ -28,10 +28,13 @@ class VATHook(BaseWrapperHook):
         )
         src_vat_loss = self.loss_fn(src_imgs, src_logits, combined_model)
         target_vat_loss = self.loss_fn(target_imgs, target_logits, combined_model)
-        return {
-            "src_vat_loss": src_vat_loss,
-            "target_vat_loss": target_vat_loss,
-        }, outputs
+        return (
+            outputs,
+            {
+                "src_vat_loss": src_vat_loss,
+                "target_vat_loss": target_vat_loss,
+            },
+        )
 
     def _loss_keys(self):
         return ["src_vat_loss", "target_vat_loss"]
