@@ -1,14 +1,25 @@
 from typing import List, Union
 
-import numpy as np
 import torch
-from pytorch_metric_learning.distances import LpDistance
+from pytorch_metric_learning.distances import BatchedDistance, LpDistance
 from pytorch_metric_learning.utils import common_functions as pml_cf
 
 from ..utils import common_functions as c_f
 from . import utils as l_u
 
 
+def check_batch_sizes(s, t, mmd_type):
+    if mmd_type == "quadratic":
+        return
+    is_list = c_f.is_list_or_tuple(s)
+    if (is_list and any(s[i].shape != t[i].shape for i in range(len(s)))) or (
+        not is_list and s.shape != t.shape
+    ):
+        raise ValueError(
+            "For mmd_type 'linear', source and target must have the same batch size."
+        )
+
+
 class MMDLoss(torch.nn.Module):
     """
     Implementation of
@@ -19,7 +30,11 @@ class MMDLoss(torch.nn.Module):
     """
 
     def __init__(
-        self, kernel_scales: Union[float, torch.Tensor] = 1, mmd_type: str = "linear"
+        self,
+        kernel_scales: Union[float, torch.Tensor] = 1,
+        mmd_type: str = "linear",
+        dist_func=None,
+        bandwidth=None,
     ):
         """
         Arguments:
@@ -29,7 +44,10 @@ class MMDLoss(torch.nn.Module):
         """
         super().__init__()
         self.kernel_scales = kernel_scales
-        self.dist_func = LpDistance(normalize_embeddings=False, p=2, power=2)
+        self.dist_func = c_f.default(
+            dist_func, LpDistance(normalize_embeddings=False, p=2, power=2)
+        )
+        self.bandwidth = bandwidth
         self.mmd_type = mmd_type
         if mmd_type == "linear":
             self.mmd_func = l_u.get_mmd_linear
@@ -51,7 +69,8 @@ class MMDLoss(torch.nn.Module):
         Returns:
             MMD if the inputs are tensors, and Joint MMD (JMMD) if the inputs are lists of tensors.
         """
-        xx, yy, zz, scale = l_u.get_mmd_dist_mats(x, y, self.dist_func)
+        check_batch_sizes(x, y, self.mmd_type)
+        xx, yy, zz, scale = l_u.get_mmd_dist_mats(x, y, self.dist_func, self.bandwidth)
         if torch.is_tensor(self.kernel_scales):
             s = scale[0] if c_f.is_list_or_tuple(scale) else scale
             self.kernel_scales = pml_cf.to_device(self.kernel_scales, s, dtype=s.dtype)
@@ -67,3 +86,25 @@ class MMDLoss(torch.nn.Module):
     def extra_repr(self):
         """"""
         return c_f.extra_repr(self, ["mmd_type", "kernel_scales"])
+
+
+class MMDBatchedLoss(MMDLoss):
+    def __init__(self, batch_size=1024, **kwargs):
+        super().__init__(**kwargs)
+        if self.mmd_type != "quadratic":
+            raise ValueError("mmd_type must be 'quadratic'")
+        self.mmd_func = l_u.get_mmd_quadratic_batched
+        self.dist_func = BatchedDistance(self.dist_func, batch_size=batch_size)
+
+    def forward(self, x: torch.Tensor, y: torch.Tensor) -> torch.Tensor:
+        """
+        Arguments:
+            x: features from one domain.
+            y: features from the other domain.
+        Returns:
+            MMD
+        """
+        if c_f.is_list_or_tuple(x) or c_f.is_list_or_tuple(y):
+            raise TypeError("List of features not yet supported")
+        check_batch_sizes(x, y, self.mmd_type)
+        return self.mmd_func(x, y, self.dist_func, self.kernel_scales, self.bandwidth)
